********************************************************
* Denne fil indeholder de STATA-kommandoer, der er brugt i
* forbindelse forelsningen i 
* Biostatistik Fllesmodulet uge 10 MPH efterr 2006
********************************************************

*define arbejdsfolder
********************************************************
cd E:\kurser\MPH\FllesModul\STAT5
********************************************************
*Vlge Svend Juuls graf set op som default.
*Dette er ikke ndvendig, men gr graferne 
*lidt pnere. Bemrk at lean1 og lean2
*skal down loades.
********************************************************
set scheme lean1
********************************************************
* tegniger og analyser af fdselsvgt
********************************************************

use w2031,clear
hist barnvaeg,start(2000) width(250) normal freq
graph export w2031.wmf,replace

qnorm barnvaeg , mco(red) 
graph export w2031qq.wmf,replace

ttest barnvaeg=3550
ttesti 2031 3558 448 3550

********************************************************
* Tegniger af triglyserid data
********************************************************

use Tri,clear
qnorm trigly if gruppe==5, mcolor(red) title("gruppe 5")    xlab( 0(0.5)2) 
graph save triqq5,replace
forvalue i=1(1)4 { 
     qnorm trigly if(gruppe==`i'),mcolor(red) title( "gruppe `i'") ///
      ylab( 0(0.5)1.5)    xlab( 0(0.5)1.5) 
     graph save triqq`i',replace 
}
graph combine triqq1.gph triqq2.gph triqq3.gph triqq4.gph
graph save part1, replace
graph combine part1.gph triqq5.gph
graph export triqq.wmf,replace

qnorm lntri if gruppe==5, mcolor(red) title("gruppe 5") ///
   ylab( -2(0.5).5)    xlab( -2(0.5).5)
graph save lntriqq5,replace
forvalue i=1(1)4 { 
     qnorm lntri if(gruppe==`i'),mcolor(red) title( "gruppe `i'") ///
     ylab( -2(0.5).5)    xlab( -2(0.5).5) 
     graph save triqq`i',replace 
}
graph combine triqq1.gph triqq2.gph triqq3.gph triqq4.gph
graph save part1, replace
graph combine part1.gph lntriqq5.gph
graph export lntriqq.wmf,replace

********************************************************
* Sammenligning af SBP
********************************************************

use fram,clear
histogram sbp if(sex==1& age<50), ///
     freq norm title("mnd") xlab(100(50)300)
graph save sbpmale,replace
histogram sbp if(sex==2& age<50), ///
     freq norm title("kvinder") xlab(100(50)300)
graph save sbpfemale,replace
qnorm sbp if(sex==1& age<50), ///
     mco(red)title("mnd") xlab(50(50)300) ylab(50(50)300)
graph save sbpmaleqq,replace
qnorm sbp if(sex==2& age<50), ///
     mco(red)title("kvinder") xlab(50(50)300) ylab(50(50)300)
graph save sbpfemaleqq,replace
graph combine sbpmale.gph sbpfemale.gph sbpmaleqq.gph sbpfemaleqq.gph
graph export sbf.wmf,replace

table sex if age<50 ,c(n sbp mean sbp  sd sbp med sbp )
ttest sbp  if age<50,by(sex)

********************************************************
* Sammenligning af SBP ln-transformeret data
********************************************************


gene lnsbp=log(sbp)
label variable lnsbp "ln sbp"
histogram lnsbp if(sex==1& age<50), ///
      freq norm title("mnd") xlab(4.4(0.2)5.8)
graph save sbpmale,replace
histogram lnsbp if(sex==2& age<50), ///
     freq norm title("kvinder") xlab(4.4(0.2)5.8)
graph save sbpfemale,replace
qnorm lnsbp if(sex==1& age<50), ///
     mco(red)title("mnd") xlab(4.4(0.2)5.8) ylab(4.4(0.2)5.8)
graph save sbpmaleqq,replace
qnorm lnsbp if(sex==2& age<50), ///
     mco(red)title("kvinder") xlab(4.4(0.2)5.8) ylab(4.4(0.2)5.8)
graph save sbpfemaleqq,replace
graph combine sbpmale.gph sbpfemale.gph sbpmaleqq.gph sbpfemaleqq.gph
graph export lnsbf.wmf,replace

ttest lnsbp  if age<50,by(sex)

********************************************************
* Sammenligning af SBP: 1. us. og 10. us
********************************************************


twoway(scatter sbp10 sbp if(age<50), mco(red) msy(o) ) ///
     (function y=x ,range(80 320)) ///
    , legend(off) xlab(80(80)320) ylab(80(80)320) ///
     xtitle("sbp us 1") ytitle("sbp us 10") aspect(1)
graph export sbp1_10.wmf,replace

generate  sbpdif=sbp10-sbp if(age<50)
generate sbpsum=sbp+sbp10 if(age<50)
label var sbpdif "sbp10-sbp"
label var sbpsum "sbp10+sbp"

histogram sbpdif,freq normal
graph export sbpdif.wmf,replace
scatter sbpdif sbpsum, ylab(-150(50)150) scheme(lean2) mco(red) msy(o) 
graph export sbpdifsum.wmf,replace

ttest sbp10=sbp if(age<50)

********************************************************
* Sammenligning af SBP: 1. us. og 10. us, ln-transform
********************************************************

twoway(scatter sbp10 sbp if(age<50), mco(red) msy(o) ) ///
      (function y=x ,range(80 320)) ///
    , legend(off)yscale(log) xscale(log) xlab(80(80)320) ///
      ylab(80(80)320)xtitle("sbp us 1") ytitle("sbp us 10") aspect(1)
graph save lnsbp1_10,replace
generate  lnsbpdif=log(sbp10)-log(sbp) if(age<50)
generate lnsbpsum=log(sbp10)+log(sbp) if(age<50)
label var lnsbpdif "ln(sbp10)-ln(sbp)"
label var lnsbpsum "ln(sbp10)+ln(sbp)"

histogram lnsbpdif,freq normal
graph save lnsbpdifhist,replace
scatter lnsbpdif lnsbpsum, ylab(-.5(.25).5) scheme(lean2) mco(red)msy(o)
graph save lnsbpdifsum,replace
graph combine lnsbp1_10.gph lnsbpdifsum.gph lnsbpdifhist.gph
graph export lnsbp.wmf,replace

ttest lnsbpdif=0

********************************************************
* Ikke parametrisk analyse af SBP
********************************************************

ranksum sbp  if age<50,by(sex)
signrank sbp=sbp10 if(age<50)



********************************************************
* tegnig af ttheder for t fordelinger og standard normal
********************************************************
twoway (function NO1=normden(x), ///
     range(-5 5) clcolor(black) clpat(solid) clwidth(thick)) ///
       (function t1=tden(1,abs(x)), ///
     range(-5 5) clcolor(black) clpat(dash) clwidth(medthick)) ///
       (function t3=tden(3,abs(x)), ///
     range(-5 5) clcolor(red) clpat(dash_dot) clwidth(medthick)) ///
       (function t30=tden(30,abs(x)), ///
     range(-5 5) clcolor(blue) clpat(dot) clwidth(medthick)) ///
       ,legend(position(11) ring(0)) xlabel(-5(1)5)
graph export tdens.wmf,replace





